@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2020 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -49,8 +48,8 @@ master_doc = 'index'
 exclude_patterns = ['_build']
 
 # General information about the project.
-project = u'TaskFlow'
-copyright = u'%s, OpenStack Foundation' % datetime.date.today().year
+project = 'TaskFlow'
+copyright = '%s, OpenStack Foundation' % datetime.date.today().year
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -68,8 +67,8 @@ modindex_common_prefix = ['taskflow.']
 # Shortened external links.
 source_tree = 'https://opendev.org/openstack/taskflow/src/branch/master/'
 extlinks = {
-    'example': (source_tree + '/taskflow/examples/%s.py', ''),
-    'pybug': ('http://bugs.python.org/issue%s', ''),
+    'example': (source_tree + '/taskflow/examples/%s.py', '%s'),
+    'pybug': ('http://bugs.python.org/issue%s', '%s'),
 }
 
 
