@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -19,7 +17,7 @@ from oslo_utils import reflection
 from taskflow.engines.action_engine import executor
 
 
-class Endpoint(object):
+class Endpoint:
     """Represents a single task with execute/revert methods."""
 
     def __init__(self, task_cls):
