@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2012-2013 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -46,7 +44,7 @@ from taskflow import task
 # more uniform manner).
 class Provider(task.Task):
     def __init__(self, name, *args, **kwargs):
-        super(Provider, self).__init__(name=name, **kwargs)
+        super().__init__(name=name, **kwargs)
         self._provide = args
 
     def execute(self):
