@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2013 Rackspace Hosting Inc. All Rights Reserved.
 #    Copyright (C) 2013 Yahoo! Inc. All Rights Reserved.
 #
@@ -24,6 +22,7 @@ import time
 import enum
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
+import tenacity
 
 from taskflow import exceptions as excp
 from taskflow import states
@@ -31,6 +30,10 @@ from taskflow.types import notifier
 from taskflow.utils import iter_utils
 
 
+RETRY_ATTEMPTS = 3
+RETRY_WAIT_TIMEOUT = 5
+
+
 class JobPriority(enum.Enum):
     """Enum of job priorities (modeled after hadoop job priorities)."""
 
@@ -105,7 +108,7 @@ class JobPriority(enum.Enum):
                 return tuple(values)
 
 
-class Job(object, metaclass=abc.ABCMeta):
+class Job(metaclass=abc.ABCMeta):
     """A abstraction that represents a named and trackable unit of work.
 
     A job connects a logbook, a owner, a priority, last modified and created
@@ -142,11 +145,13 @@ class Job(object, metaclass=abc.ABCMeta):
             book_data = {}
         self._book_data = book_data
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def last_modified(self):
         """The datetime the job was last modified."""
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def created_on(self):
         """The datetime the job was created on."""
 
@@ -155,11 +160,13 @@ class Job(object, metaclass=abc.ABCMeta):
         """The board this job was posted on or was created from."""
         return self._board
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def state(self):
         """Access the current state of this job."""
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def priority(self):
         """The :py:class:`~.JobPriority` of this job."""
 
@@ -247,6 +254,11 @@ class Job(object, metaclass=abc.ABCMeta):
         """The non-uniquely identifying name of this job."""
         return self._name
 
+    @tenacity.retry(retry=tenacity.retry_if_exception_type(
+                    exception_types=excp.StorageFailure),
+                    stop=tenacity.stop_after_attempt(RETRY_ATTEMPTS),
+                    wait=tenacity.wait_fixed(RETRY_WAIT_TIMEOUT),
+                    reraise=True)
     def _load_book(self):
         book_uuid = self.book_uuid
         if self._backend is not None and book_uuid is not None:
@@ -263,12 +275,12 @@ class Job(object, metaclass=abc.ABCMeta):
     def __str__(self):
         """Pretty formats the job into something *more* meaningful."""
         cls_name = type(self).__name__
-        return "%s: %s (priority=%s, uuid=%s, details=%s)" % (
+        return "{}: {} (priority={}, uuid={}, details={})".format(
             cls_name, self.name, self.priority,
             self.uuid, self.details)
 
 
-class JobBoardIterator(object):
+class JobBoardIterator:
     """Iterator over a jobboard that iterates over potential jobs.
 
     It provides the following attributes:
@@ -341,7 +353,7 @@ class JobBoardIterator(object):
             return job
 
 
-class JobBoard(object, metaclass=abc.ABCMeta):
+class JobBoard(metaclass=abc.ABCMeta):
     """A place where jobs can be posted, reposted, claimed and transferred.
 
     There can be multiple implementations of this job board, depending on the
@@ -397,7 +409,8 @@ class JobBoard(object, metaclass=abc.ABCMeta):
             appear (if None then waits forever).
         """
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def job_count(self):
         """Returns how many jobs are on this jobboard.
 
@@ -516,7 +529,8 @@ class JobBoard(object, metaclass=abc.ABCMeta):
         :type entity: :py:class:`~taskflow.types.entity.Entity`
         """
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def connected(self):
         """Returns if this jobboard is connected."""
 
@@ -549,7 +563,7 @@ class NotifyingJobBoard(JobBoard):
     registered are thread safe (and block for as little time as possible).
     """
     def __init__(self, name, conf):
-        super(NotifyingJobBoard, self).__init__(name, conf)
+        super().__init__(name, conf)
         self.notifier = notifier.Notifier()
 
 
