@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,8 +15,6 @@
 import logging
 import os
 
-import six
-
 from taskflow import exceptions
 from taskflow.listeners import base
 from taskflow import states
@@ -51,14 +47,14 @@ class CheckingClaimListener(base.Listener):
     """
 
     def __init__(self, engine, job, board, owner, on_job_loss=None):
-        super(CheckingClaimListener, self).__init__(engine)
+        super().__init__(engine)
         self._job = job
         self._board = board
         self._owner = owner
         if on_job_loss is None:
             self._on_job_loss = self._suspend_engine_on_loss
         else:
-            if not six.callable(on_job_loss):
+            if not callable(on_job_loss):
                 raise ValueError("Custom 'on_job_loss' handler must be"
                                  " callable")
             self._on_job_loss = on_job_loss
