@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2012 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,8 +13,7 @@
 #    under the License.
 
 import collections
-
-import six
+import functools
 
 from taskflow import deciders as de
 from taskflow import exceptions as exc
@@ -67,7 +64,7 @@ class Flow(flow.Flow):
     """
 
     def __init__(self, name, retry=None):
-        super(Flow, self).__init__(name, retry)
+        super().__init__(name, retry)
         self._graph = gr.DiGraph(name=name)
         self._graph.freeze()
 
@@ -109,7 +106,7 @@ class Flow(flow.Flow):
         if not self._graph.has_node(v):
             raise ValueError("Node '%s' not found to link to" % (v))
         if decider is not None:
-            if not six.callable(decider):
+            if not callable(decider):
                 raise ValueError("Decider boolean callback must be callable")
         self._swap(self._link(u, v, manual=True,
                               decider=decider, decider_depth=decider_depth))
@@ -316,7 +313,7 @@ class Flow(flow.Flow):
 def _reset_cached_subgraph(func):
     """Resets cached subgraph after execution, in case it was affected."""
 
-    @six.wraps(func)
+    @functools.wraps(func)
     def wrapper(self, *args, **kwargs):
         result = func(self, *args, **kwargs)
         self._subgraph = None
@@ -333,7 +330,7 @@ class TargetedFlow(Flow):
     """
 
     def __init__(self, *args, **kwargs):
-        super(TargetedFlow, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._subgraph = None
         self._target = None
 
