@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2013 Rackspace Hosting Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -16,7 +14,6 @@
 
 import contextlib
 
-import six
 from stevedore import driver
 
 from taskflow import exceptions as exc
@@ -51,30 +48,21 @@ def fetch(conf, namespace=BACKEND_NAMESPACE, **kwargs):
     is ``{'a': 'b', 'c': 'd'}`` to the constructor of that persistence backend
     instance.
     """
-    if isinstance(conf, six.string_types):
-        conf = {'connection': conf}
-    backend_name = conf['connection']
-    try:
-        uri = misc.parse_uri(backend_name)
-    except (TypeError, ValueError):
-        pass
-    else:
-        backend_name = uri.scheme
-        conf = misc.merge_uri(uri, conf.copy())
+    backend, conf = misc.extract_driver_and_conf(conf, 'connection')
     # If the backend is like 'mysql+pymysql://...' which informs the
     # backend to use a dialect (supported by sqlalchemy at least) we just want
     # to look at the first component to find our entrypoint backend name...
-    if backend_name.find("+") != -1:
-        backend_name = backend_name.split("+", 1)[0]
-    LOG.debug('Looking for %r backend driver in %r', backend_name, namespace)
+    if backend.find("+") != -1:
+        backend = backend.split("+", 1)[0]
+    LOG.debug('Looking for %r backend driver in %r', backend, namespace)
     try:
-        mgr = driver.DriverManager(namespace, backend_name,
+        mgr = driver.DriverManager(namespace, backend,
                                    invoke_on_load=True,
                                    invoke_args=(conf,),
                                    invoke_kwds=kwargs)
         return mgr.driver
     except RuntimeError as e:
-        raise exc.NotFound("Could not find backend %s: %s" % (backend_name, e))
+        raise exc.NotFound("Could not find backend {}: {}".format(backend, e))
 
 
 @contextlib.contextmanager
