@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2012 Yahoo! Inc. All Rights Reserved.
 #    Copyright (C) 2013 Rackspace Hosting All Rights Reserved.
 #
@@ -20,9 +18,7 @@ import copy
 import itertools
 import posixpath as pp
 
-from debtcollector import removals
 import fasteners
-import six
 
 from taskflow import exceptions as exc
 from taskflow.persistence import path_based
@@ -33,10 +29,10 @@ class FakeInode(tree.Node):
     """A in-memory filesystem inode-like object."""
 
     def __init__(self, item, path, value=None):
-        super(FakeInode, self).__init__(item, path=path, value=value)
+        super().__init__(item, path=path, value=value)
 
 
-class FakeFilesystem(object):
+class FakeFilesystem:
     """An in-memory filesystem-like structure.
 
     This filesystem uses posix style paths **only** so users must be careful
@@ -53,7 +49,7 @@ class FakeFilesystem(object):
     :meth:`~taskflow.persistence.backends.impl_memory.FakeFilesystem.get`
     or other read-only actions (like calling into
     :meth:`~taskflow.persistence.backends.impl_memory.FakeFilesystem.ls`)
-    are occuring at the same time.
+    are occurring at the same time.
 
     Example usage:
 
@@ -193,35 +189,14 @@ class FakeFilesystem(object):
         return [selector_func(node, child_node)
                 for child_node in node.bfs_iter()]
 
-    @removals.removed_kwarg('recursive', version="0.11", removal_version="2.0")
-    def ls(self, path, recursive=False):
-        """Return list of all children of the given path.
-
-        NOTE(harlowja): if ``recursive`` is passed in as truthy then the
-        absolute path is **always** returned (not the relative path). If
-        ``recursive`` is left as the default or falsey then the
-        relative path is **always** returned.
-
-        This is documented in bug `1458114`_ and the existing behavior is
-        being maintained, to get a recursive version that is absolute (or is
-        not absolute) it is recommended to use the :py:meth:`.ls_r` method
-        instead.
-
-        .. deprecated:: 0.11
-
-          In a future release the ``recursive`` keyword argument will
-          be removed (so preferring and moving to the :py:meth:`.ls_r` should
-          occur earlier rather than later).
-
-        .. _1458114: https://bugs.launchpad.net/taskflow/+bug/1458114
-        """
+    def ls(self, path, absolute=False):
+        """Return list of all children of the given path (not recursive)."""
         node = self._fetch_node(path)
-        if recursive:
+        if absolute:
             selector_func = self._metadata_path_selector
-            child_node_it = node.bfs_iter()
         else:
             selector_func = self._up_to_root_selector
-            child_node_it = iter(node)
+        child_node_it = iter(node)
         return [selector_func(node, child_node)
                 for child_node in child_node_it]
 
@@ -272,8 +247,7 @@ class FakeFilesystem(object):
             parts = path.split(pp.sep)[1:]
         if include_root:
             parts.insert(0, self._root.item)
-        for piece in parts:
-            yield piece
+        yield from parts
 
     def __delitem__(self, path):
         self.delete(path, recursive=True)
@@ -281,9 +255,9 @@ class FakeFilesystem(object):
     @staticmethod
     def _stringify_node(node):
         if 'target' in node.metadata:
-            return "%s (link to %s)" % (node.item, node.metadata['target'])
+            return "{} (link to {})".format(node.item, node.metadata['target'])
         else:
-            return six.text_type(node.item)
+            return str(node.item)
 
     def pformat(self):
         """Pretty format this in-memory filesystem."""
@@ -332,7 +306,7 @@ class MemoryBackend(path_based.PathBasedBackend):
     DEFAULT_PATH = pp.sep
 
     def __init__(self, conf=None):
-        super(MemoryBackend, self).__init__(conf)
+        super().__init__(conf)
         self.memory = FakeFilesystem(deep_copy=self._conf.get('deep_copy',
                                                               True))
         self.lock = fasteners.ReaderWriterLock()
@@ -346,7 +320,7 @@ class MemoryBackend(path_based.PathBasedBackend):
 
 class Connection(path_based.PathBasedConnection):
     def __init__(self, backend):
-        super(Connection, self).__init__(backend)
+        super().__init__(backend)
         self.upgrade()
 
     @contextlib.contextmanager
