@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2012 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -33,9 +31,9 @@ def _replicate_graph_with_names(compilation):
     # original/source flow).
     g = compilation.execution_graph
     n_g = g.__class__(name=g.name)
-    for node, node_data in g.nodes_iter(data=True):
+    for node, node_data in g.nodes(data=True):
         n_g.add_node(node.name, attr_dict=node_data)
-    for u, v, u_v_data in g.edges_iter(data=True):
+    for u, v, u_v_data in g.edges(data=True):
         n_g.add_edge(u.name, v.name, attr_dict=u_v_data)
     return n_g
 
@@ -100,7 +98,7 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(6, len(g))
-        self.assertItemsEqual(g.edges(), [
+        self.assertCountEqual(g.edges(), [
             ('test', 'a'),
             ('test', 'b'),
             ('test', 'c'),
@@ -110,7 +108,7 @@ class PatternCompileTest(test.TestCase):
             ('c', 'test[$]'),
             ('d', 'test[$]'),
         ])
-        self.assertEqual(set(['test']), set(g.no_predecessors_iter()))
+        self.assertEqual({'test'}, set(g.no_predecessors_iter()))
 
     def test_linear_nested(self):
         a, b, c, d = test_utils.make_many(4)
@@ -148,7 +146,7 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(8, len(g))
-        self.assertItemsEqual(g.edges(), [
+        self.assertCountEqual(g.edges(), [
             ('test', 'a'),
             ('test', 'b'),
             ('test', 'test2'),
@@ -168,7 +166,7 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(8, len(g))
-        self.assertItemsEqual(g.edges(), [
+        self.assertCountEqual(g.edges(), [
             ('lt', 'a'),
             ('a', 'ut'),
             ('ut', 'b'),
@@ -199,7 +197,7 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(11, len(g))
-        self.assertItemsEqual(g.edges(), [
+        self.assertCountEqual(g.edges(), [
             ('test', 'a'),
             ('test', 'b'),
             ('test', 'c'),
@@ -230,7 +228,7 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(11, len(g))
-        self.assertItemsEqual(g.edges(), [
+        self.assertCountEqual(g.edges(), [
             ('test', 'a'),
             ('test', 'b'),
             ('test', 'c'),
@@ -263,15 +261,15 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(6, len(g))
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'a', {'invariant': True}),
             ('a', 'b', {'manual': True}),
             ('b', 'c', {'manual': True}),
             ('c', 'd', {'manual': True}),
             ('d', 'test[$]', {'invariant': True}),
         ])
-        self.assertItemsEqual(['test'], g.no_predecessors_iter())
-        self.assertItemsEqual(['test[$]'], g.no_successors_iter())
+        self.assertCountEqual(['test'], g.no_predecessors_iter())
+        self.assertCountEqual(['test[$]'], g.no_successors_iter())
 
     def test_graph_dependencies(self):
         a = test_utils.ProvidesRequiresTask('a', provides=['x'], requires=[])
@@ -281,13 +279,13 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(4, len(g))
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'a', {'invariant': True}),
-            ('a', 'b', {'reasons': set(['x'])}),
+            ('a', 'b', {'reasons': {'x'}}),
             ('b', 'test[$]', {'invariant': True}),
         ])
-        self.assertItemsEqual(['test'], g.no_predecessors_iter())
-        self.assertItemsEqual(['test[$]'], g.no_successors_iter())
+        self.assertCountEqual(['test'], g.no_predecessors_iter())
+        self.assertCountEqual(['test[$]'], g.no_successors_iter())
 
     def test_graph_nested_requires(self):
         a = test_utils.ProvidesRequiresTask('a', provides=['x'], requires=[])
@@ -299,16 +297,16 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(7, len(g))
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'a', {'invariant': True}),
             ('test2', 'b', {'invariant': True}),
-            ('a', 'test2', {'reasons': set(['x'])}),
+            ('a', 'test2', {'reasons': {'x'}}),
             ('b', 'c', {'invariant': True}),
             ('c', 'test2[$]', {'invariant': True}),
             ('test2[$]', 'test[$]', {'invariant': True}),
         ])
-        self.assertItemsEqual(['test'], list(g.no_predecessors_iter()))
-        self.assertItemsEqual(['test[$]'], list(g.no_successors_iter()))
+        self.assertCountEqual(['test'], list(g.no_predecessors_iter()))
+        self.assertCountEqual(['test[$]'], list(g.no_successors_iter()))
 
     def test_graph_nested_provides(self):
         a = test_utils.ProvidesRequiresTask('a', provides=[], requires=['x'])
@@ -320,19 +318,19 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(7, len(g))
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'test2', {'invariant': True}),
             ('a', 'test[$]', {'invariant': True}),
 
             # The 'x' requirement is produced out of test2...
-            ('test2[$]', 'a', {'reasons': set(['x'])}),
+            ('test2[$]', 'a', {'reasons': {'x'}}),
 
             ('test2', 'b', {'invariant': True}),
             ('b', 'c', {'invariant': True}),
             ('c', 'test2[$]', {'invariant': True}),
         ])
-        self.assertItemsEqual(['test'], g.no_predecessors_iter())
-        self.assertItemsEqual(['test[$]'], g.no_successors_iter())
+        self.assertCountEqual(['test'], g.no_predecessors_iter())
+        self.assertCountEqual(['test[$]'], g.no_successors_iter())
 
     def test_empty_flow_in_linear_flow(self):
         flo = lf.Flow('lf')
@@ -343,7 +341,7 @@ class PatternCompileTest(test.TestCase):
 
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
-        self.assertItemsEqual(g.edges(), [
+        self.assertCountEqual(g.edges(), [
             ("lf", "a"),
             ("a", "empty"),
             ("empty", "empty[$]"),
@@ -435,7 +433,7 @@ class PatternCompileTest(test.TestCase):
         empty_flow_terminal = empty_flow_successors[0]
         self.assertIs(empty_flow, empty_flow_terminal.flow)
         self.assertEqual(compiler.FLOW_END,
-                         g.node[empty_flow_terminal]['kind'])
+                         g.nodes[empty_flow_terminal]['kind'])
         self.assertTrue(g.has_edge(empty_flow_terminal, b))
 
     def test_empty_flow_in_graph_flow_linkage(self):
@@ -499,16 +497,16 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(6, len(g))
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'c1', {'invariant': True}),
             ('c1', 'test2', {'invariant': True, 'retry': True}),
             ('test2', 'c2', {'invariant': True}),
             ('c2', 'test2[$]', {'invariant': True}),
             ('test2[$]', 'test[$]', {'invariant': True}),
         ])
-        self.assertIs(c1, g.node['c2']['retry'])
-        self.assertItemsEqual(['test'], list(g.no_predecessors_iter()))
-        self.assertItemsEqual(['test[$]'], list(g.no_successors_iter()))
+        self.assertIs(c1, g.nodes['c2']['retry'])
+        self.assertCountEqual(['test'], list(g.no_predecessors_iter()))
+        self.assertCountEqual(['test[$]'], list(g.no_successors_iter()))
 
     def test_retry_in_linear_flow_with_tasks(self):
         c = retry.AlwaysRevert("c")
@@ -518,17 +516,17 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(5, len(g))
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'c', {'invariant': True}),
             ('a', 'b', {'invariant': True}),
             ('c', 'a', {'invariant': True, 'retry': True}),
             ('b', 'test[$]', {'invariant': True}),
         ])
 
-        self.assertItemsEqual(['test'], g.no_predecessors_iter())
-        self.assertItemsEqual(['test[$]'], g.no_successors_iter())
-        self.assertIs(c, g.node['a']['retry'])
-        self.assertIs(c, g.node['b']['retry'])
+        self.assertCountEqual(['test'], g.no_predecessors_iter())
+        self.assertCountEqual(['test[$]'], g.no_successors_iter())
+        self.assertIs(c, g.nodes['a']['retry'])
+        self.assertIs(c, g.nodes['b']['retry'])
 
     def test_retry_in_unordered_flow_with_tasks(self):
         c = retry.AlwaysRevert("c")
@@ -538,7 +536,7 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(5, len(g))
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'c', {'invariant': True}),
             ('c', 'a', {'invariant': True, 'retry': True}),
             ('c', 'b', {'invariant': True, 'retry': True}),
@@ -546,10 +544,10 @@ class PatternCompileTest(test.TestCase):
             ('a', 'test[$]', {'invariant': True}),
         ])
 
-        self.assertItemsEqual(['test'], list(g.no_predecessors_iter()))
-        self.assertItemsEqual(['test[$]'], list(g.no_successors_iter()))
-        self.assertIs(c, g.node['a']['retry'])
-        self.assertIs(c, g.node['b']['retry'])
+        self.assertCountEqual(['test'], list(g.no_predecessors_iter()))
+        self.assertCountEqual(['test[$]'], list(g.no_successors_iter()))
+        self.assertIs(c, g.nodes['a']['retry'])
+        self.assertIs(c, g.nodes['b']['retry'])
 
     def test_retry_in_graph_flow_with_tasks(self):
         r = retry.AlwaysRevert("r")
@@ -558,7 +556,7 @@ class PatternCompileTest(test.TestCase):
 
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'r', {'invariant': True}),
             ('r', 'a', {'invariant': True, 'retry': True}),
             ('r', 'b', {'invariant': True, 'retry': True}),
@@ -567,11 +565,11 @@ class PatternCompileTest(test.TestCase):
             ('c', 'test[$]', {'invariant': True}),
         ])
 
-        self.assertItemsEqual(['test'], g.no_predecessors_iter())
-        self.assertItemsEqual(['test[$]'], g.no_successors_iter())
-        self.assertIs(r, g.node['a']['retry'])
-        self.assertIs(r, g.node['b']['retry'])
-        self.assertIs(r, g.node['c']['retry'])
+        self.assertCountEqual(['test'], g.no_predecessors_iter())
+        self.assertCountEqual(['test[$]'], g.no_successors_iter())
+        self.assertIs(r, g.nodes['a']['retry'])
+        self.assertIs(r, g.nodes['b']['retry'])
+        self.assertIs(r, g.nodes['c']['retry'])
 
     def test_retries_hierarchy(self):
         c1 = retry.AlwaysRevert("c1")
@@ -583,7 +581,7 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(10, len(g))
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'c1', {'invariant': True}),
             ('c1', 'a', {'invariant': True, 'retry': True}),
             ('a', 'test2', {'invariant': True}),
@@ -594,12 +592,12 @@ class PatternCompileTest(test.TestCase):
             ('test2[$]', 'd', {'invariant': True}),
             ('d', 'test[$]', {'invariant': True}),
         ])
-        self.assertIs(c1, g.node['a']['retry'])
-        self.assertIs(c1, g.node['d']['retry'])
-        self.assertIs(c2, g.node['b']['retry'])
-        self.assertIs(c2, g.node['c']['retry'])
-        self.assertIs(c1, g.node['c2']['retry'])
-        self.assertIsNone(g.node['c1'].get('retry'))
+        self.assertIs(c1, g.nodes['a']['retry'])
+        self.assertIs(c1, g.nodes['d']['retry'])
+        self.assertIs(c2, g.nodes['b']['retry'])
+        self.assertIs(c2, g.nodes['c']['retry'])
+        self.assertIs(c1, g.nodes['c2']['retry'])
+        self.assertIsNone(g.nodes['c1'].get('retry'))
 
     def test_retry_subflows_hierarchy(self):
         c1 = retry.AlwaysRevert("c1")
@@ -610,7 +608,7 @@ class PatternCompileTest(test.TestCase):
         g = _replicate_graph_with_names(
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(9, len(g))
-        self.assertItemsEqual(g.edges(data=True), [
+        self.assertCountEqual(g.edges(data=True), [
             ('test', 'c1', {'invariant': True}),
             ('c1', 'a', {'invariant': True, 'retry': True}),
             ('a', 'test2', {'invariant': True}),
@@ -620,8 +618,8 @@ class PatternCompileTest(test.TestCase):
             ('test2[$]', 'd', {'invariant': True}),
             ('d', 'test[$]', {'invariant': True}),
         ])
-        self.assertIs(c1, g.node['a']['retry'])
-        self.assertIs(c1, g.node['d']['retry'])
-        self.assertIs(c1, g.node['b']['retry'])
-        self.assertIs(c1, g.node['c']['retry'])
-        self.assertIsNone(g.node['c1'].get('retry'))
+        self.assertIs(c1, g.nodes['a']['retry'])
+        self.assertIs(c1, g.nodes['d']['retry'])
+        self.assertIs(c1, g.nodes['b']['retry'])
+        self.assertIs(c1, g.nodes['c']['retry'])
+        self.assertIsNone(g.nodes['c1'].get('retry'))
