@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2013 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -137,7 +135,7 @@ class ZookeeperJobboardTest(test.TestCase, ZookeeperBoardTestMixin):
         return (client, board)
 
     def setUp(self):
-        super(ZookeeperJobboardTest, self).setUp()
+        super().setUp()
         self.client, self.board = self.create_board()
 
 
@@ -152,7 +150,7 @@ class ZakeJobboardTest(test.TestCase, ZookeeperBoardTestMixin):
         return (client, board)
 
     def setUp(self):
-        super(ZakeJobboardTest, self).setUp()
+        super().setUp()
         self.client, self.board = self.create_board()
         self.bad_paths = [self.board.path, self.board.trash_path]
         self.bad_paths.extend(zake_utils.partition_path(self.board.path))
@@ -271,12 +269,12 @@ class ZakeJobboardTest(test.TestCase, ZookeeperBoardTestMixin):
         with base.connect_close(self.board):
             self.board.register_entity(entity_instance)
         # Check '.entity' node has been created
-        self.assertTrue(self.board.entity_path in self.client.storage.paths)
+        self.assertIn(self.board.entity_path, self.client.storage.paths)
 
         conductor_entity_path = k_paths.join(self.board.entity_path,
                                              'conductor',
                                              conductor_name)
-        self.assertTrue(conductor_entity_path in self.client.storage.paths)
+        self.assertIn(conductor_entity_path, self.client.storage.paths)
         conductor_data = (
             self.client.storage.paths[conductor_entity_path]['data'])
         self.assertTrue(len(conductor_data) > 0)
@@ -293,3 +291,47 @@ class ZakeJobboardTest(test.TestCase, ZookeeperBoardTestMixin):
             self.assertRaises(excp.NotImplementedError,
                               self.board.register_entity,
                               entity_instance_2)
+
+    def test_connect_check_compatible(self):
+        # Valid version
+        client = fake_client.FakeClient()
+        board = impl_zookeeper.ZookeeperJobBoard(
+            'test-board', {'check_compatible': True},
+            client=client)
+        self.addCleanup(board.close)
+        self.addCleanup(self.close_client, client)
+
+        with base.connect_close(board):
+            pass
+
+        # Invalid version, no check
+        client = fake_client.FakeClient(server_version=(3, 2, 0))
+        board = impl_zookeeper.ZookeeperJobBoard(
+            'test-board', {'check_compatible': False},
+            client=client)
+        self.addCleanup(board.close)
+        self.addCleanup(self.close_client, client)
+
+        with base.connect_close(board):
+            pass
+
+        # Invalid version, check_compatible=True
+        client = fake_client.FakeClient(server_version=(3, 2, 0))
+        board = impl_zookeeper.ZookeeperJobBoard(
+            'test-board', {'check_compatible': True},
+            client=client)
+        self.addCleanup(board.close)
+        self.addCleanup(self.close_client, client)
+
+        self.assertRaises(excp.IncompatibleVersion, board.connect)
+
+        # Invalid version, check_compatible='False'
+        client = fake_client.FakeClient(server_version=(3, 2, 0))
+        board = impl_zookeeper.ZookeeperJobBoard(
+            'test-board', {'check_compatible': 'False'},
+            client=client)
+        self.addCleanup(board.close)
+        self.addCleanup(self.close_client, client)
+
+        with base.connect_close(board):
+            pass
